<?php

/* -----------------------------------------------------------------------------
  class name: tabsheets
  class version: 1.1
  date: 2007-11-25
  ------------------------------------------------------------------------------
  author: grum at grum.dnsalias.com
  << May the Little SpaceFrog be with you >>
  ------------------------------------------------------------------------------

  this class provides base functions to manage tabsheet
  assuming that pwg templates and function exists
    - constructor tabsheets($name)
    - (public) function add($name, $caption, $url, $selected = false)
    - (public) function delete($name)
    - (public) function select($name)
    - (public) function make_tabsheets()
    - (public) function set_title_name($titlename)  -v1.1
    - (public) function get_title_name()  -v1.1
    - (public) function get_selected()  -v1.1
  ------------------------------------------------------------------------------
  HISTORY VERSION
  v1.1    + $titlename managment
          + $titlename var
          + set_titlename function
          + get_titlename function
          + modify make_tabsheet (use of a $local_tpl var rather than $template)
          + get_selected function & $selected management
              
  
 ---------------------------------------------------------------------------- */
class tabsheets
{
  var $sheets;
  var $name;
  var $titlename;   //if set, {$titlename} in the template is affected by $titlename value
  var $selected;

  /*
    $name is the tabsheet's name inside the template .tpl file 
  */
  function tabsheets($name='TABSHEET')
  {
    $this->sheets=array();
    $this->name=$name;
    $this->titlename="";
    $this->selected="";
  }

  /*
     add a tab
     $caption is translated later by l10n function, so don't assign 
     a translated name
  */
  function add($name, $caption, $url, $selected = false)
  {
  if(!isset($this->sheets[$name]))
    {
      $this->sheets[$name] = array('caption' => $caption,
                                   'url' => $url, 
                                   'selected' => $selected);
      if($selected)
      {
        $this->selected=$name;
      }
      return(true);
    }
    return(false);
  }

  /*
     remove a tab
  */
  function delete($name)
  {
  if(isset($this->sheets[$name]))
    {
      array_splice($this->sheets, $name, 1);
      if($this->selected==$name)
      {
        $this->selected="";
      }
      return(true);
    }
    return(false);
  }

  /*
     select a tab to be active
  */
  function select($name)
  {
    $this->selected=$name;
    foreach($this->sheets as $key => $val)
    {
      if($name==$key)
      {
          $this->sheets[$key]['selected']=true;
      }
      else
      {
          $this->sheets[$key]['selected']=false;
      }
    }
  }

  /*
    set $titlename value
  */
  function set_titlename($titlename)
  {
    $this->titlename=$titlename;
    return($this->titlename);
  }

  /*
    returns $titlename value
  */
  function get_titlename()
  {
    return($this->titlename);
  }

  /*
    returns properties of selected tab
  */
  function get_selected()
  {
    return($this->sheets[$this->selected]);
  }

  /*
    make tabsheet and apply it to the template

    $pages is an array of sheet
        $pages = array
    (
        'tab1' => array
         (
          'caption' => 'tab_caption'),
          'url' => 'tab_url',
          'selected' => 1 
         ),
        'tab2' => array
         (
          'caption' => 'tab_caption'),
          'url' => 'tab_url',
          'selected' => 0
         )
        )

      using a local template to permit easily use of multiple tabsheet in the same
      page
  */
  function make_tabsheets()
  {
    global $template, $user;

    if (count($this->sheets) > 0)
    {
      $local_tpl = new Template(PHPWG_ROOT_PATH.'template/'.$user['template'], "");
      $local_tpl->set_filename('tabsheet', 'admin/tabsheet.tpl');

      foreach ($this->sheets as $tab_name => $tab)
      {
        $local_tpl->assign_block_vars
        (
          'tab',
          array
          (
              'CLASSNAME' => ($tab['selected'] ? 'selected_tab' : 'normal_tab'),
              'URL' => $tab['url'],
              'CAPTION' => l10n($tab['caption'])
          )
        );
      }

      $template->assign_vars(
        array(
          $this->name => $local_tpl->parse('tabsheet', true),
          $this->titlename => '['.l10n($this->sheets[$this->selected]['caption']).']'
        )
      );
    }
  }

}//end class tabsheets


?>